=head1 Name

Starlink::ATL - Utilities for use with Starlink::AST.

=head1 SYNOPSIS

  use Starlink::ATL;

=head1 DESCRIPTION

This package contains:

=over 4

=item Starlink::ATL::Region - Tools for AST regions.

=back

=cut

package Starlink::ATL;

use strict;

use Starlink::AST;

our $VERSION = 0.05;

1;

__END__

=head1 COPYRIGHT

Copyright (C) 2021 East Asian Observatory
All Rights Reserved.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
